@@ -1,6 +1,6 @@
-package Locale::CLDR::Asa::Any;
+package Locale::CLDR::Asa::Any v0.25.0;
 # This file auto generated
-#	on Sun 23 Mar  7:15:21 pm GMT
+#	on Mon 21 Apr 10:14:26 pm GMT
 
 use v5.18;
 use mro 'c3';
