@@ -1,6 +1,6 @@
-package Locale::CLDR::Brx::Any;
+package Locale::CLDR::Brx::Any v0.25.0;
 # This file auto generated
-#	on Sun 23 Mar  7:21:52 pm GMT
+#	on Mon 21 Apr 10:25:57 pm GMT
 
 use v5.18;
 use mro 'c3';
