@@ -1,6 +1,6 @@
-package Locale::CLDR::Dua::Any;
+package Locale::CLDR::Dua::Any v0.25.0;
 # This file auto generated
-#	on Sun 23 Mar  7:27:40 pm GMT
+#	on Mon 21 Apr 10:39:00 pm GMT
 
 use v5.18;
 use mro 'c3';
