@@ -1,6 +1,6 @@
-package Locale::CLDR::Dyo::Any;
+package Locale::CLDR::Dyo::Any v0.25.0;
 # This file auto generated
-#	on Sun 23 Mar  7:27:41 pm GMT
+#	on Mon 21 Apr 10:39:01 pm GMT
 
 use v5.18;
 use mro 'c3';
