@@ -1,6 +1,6 @@
-package Locale::CLDR::El::Any;
+package Locale::CLDR::El::Any v0.25.0;
 # This file auto generated
-#	on Sun 23 Mar  7:31:18 pm GMT
+#	on Mon 21 Apr 10:45:05 pm GMT
 
 use v5.18;
 use mro 'c3';
