@@ -1,6 +1,6 @@
-package Locale::CLDR::Eu::Any;
+package Locale::CLDR::Eu::Any v0.25.0;
 # This file auto generated
-#	on Sun 23 Mar  7:35:18 pm GMT
+#	on Mon 21 Apr 10:53:05 pm GMT
 
 use v5.18;
 use mro 'c3';
