@@ -1,6 +1,6 @@
-package Locale::CLDR::Fur::Any;
+package Locale::CLDR::Fur::Any v0.25.0;
 # This file auto generated
-#	on Sun 23 Mar  7:39:01 pm GMT
+#	on Mon 21 Apr 11:00:05 pm GMT
 
 use v5.18;
 use mro 'c3';
