@@ -1,6 +1,6 @@
-package Locale::CLDR::Ga::Any;
+package Locale::CLDR::Ga::Any v0.25.0;
 # This file auto generated
-#	on Sun 23 Mar  7:39:43 pm GMT
+#	on Mon 21 Apr 11:02:43 pm GMT
 
 use v5.18;
 use mro 'c3';
