@@ -1,6 +1,6 @@
-package Locale::CLDR::Khq::Any;
+package Locale::CLDR::Khq::Any v0.25.0;
 # This file auto generated
-#	on Sun 23 Mar  7:54:28 pm GMT
+#	on Mon 21 Apr 11:27:40 pm GMT
 
 use v5.18;
 use mro 'c3';
