@@ -1,6 +1,6 @@
-package Locale::CLDR::Kln::Any;
+package Locale::CLDR::Kln::Any v0.25.0;
 # This file auto generated
-#	on Sun 23 Mar  7:56:17 pm GMT
+#	on Mon 21 Apr 11:29:51 pm GMT
 
 use v5.18;
 use mro 'c3';
