@@ -1,6 +1,6 @@
-package Locale::CLDR::Mgh::Any;
+package Locale::CLDR::Mgh::Any v0.25.0;
 # This file auto generated
-#	on Sun 23 Mar  8:31:48 pm GMT
+#	on Mon 21 Apr 11:50:09 pm GMT
 
 use v5.18;
 use mro 'c3';
