@@ -1,6 +1,6 @@
-package Locale::CLDR::Mr::Any;
+package Locale::CLDR::Mr::Any v0.25.0;
 # This file auto generated
-#	on Sun 23 Mar  8:38:49 pm GMT
+#	on Mon 21 Apr 11:59:23 pm GMT
 
 use v5.18;
 use mro 'c3';
