@@ -1,6 +1,6 @@
-package Locale::CLDR::Nd::Any;
+package Locale::CLDR::Nd::Any v0.25.0;
 # This file auto generated
-#	on Sun 23 Mar  8:41:35 pm GMT
+#	on Tue 22 Apr 12:04:12 am GMT
 
 use v5.18;
 use mro 'c3';
