@@ -1,6 +1,6 @@
-package Locale::CLDR::Ru::Any;
+package Locale::CLDR::Ru::Any v0.25.0;
 # This file auto generated
-#	on Sun 23 Mar  8:52:22 pm GMT
+#	on Tue 22 Apr 12:23:20 am GMT
 
 use v5.18;
 use mro 'c3';
