@@ -1,6 +1,6 @@
-package Locale::CLDR::Ur::Any;
+package Locale::CLDR::Ur::Any v0.25.0;
 # This file auto generated
-#	on Sun 23 Mar  9:11:24 pm GMT
+#	on Tue 22 Apr 12:54:33 am GMT
 
 use v5.18;
 use mro 'c3';
